.. _api:

API
===


.. important::

    Do not use the base class :class:`flaat.BaseFlaat` directly.
    Better use the framework specific classes :class:`flaat.flask.Flaat`, :class:`flaat.aio.Flaat` and :class:`flaat.fastapi.Flaat`.

Here is the documentation of the most important modules of `flaat` with regard to developers, that want to use flaat in the application:

flaat
-----
.. automodule:: flaat
   :members:

flaat.user_infos
----------------
.. automodule:: flaat.user_infos
   :members:

flaat.access_tokens
-------------------
.. automodule:: flaat.access_tokens
   :members:

flaat.requirements
------------------
.. automodule:: flaat.requirements
    :members:

flaat.exceptions
----------------
.. automodule:: flaat.exceptions
   :members:
